==> cdk-cloudformation-awscommunity-time-sleep-1.0.0a7.tar.gz: cdk-cloudformation-awscommunity-time-sleep-1.0.0a7/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-cloudformation-awscommunity-time-sleep",
    "version": "1.0.0.a7",
    "description": "An example resource schema demonstrating some basic constructs and validation rules.",
    "license": "Apache-2.0",
    "url": "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/cdklabs/cdk-cloudformation.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_cloudformation_awscommunity_time_sleep",
        "cdk_cloudformation_awscommunity_time_sleep._jsii"
    ],
    "package_data": {
        "cdk_cloudformation_awscommunity_time_sleep._jsii": [
            "awscommunity-time-sleep@1.0.0-alpha.7.jsii.tgz"
        ],
        "cdk_cloudformation_awscommunity_time_sleep": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.72.1, <3.0.0",
        "constructs>=10.1.302, <11.0.0",
        "jsii>=1.80.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cdk-cloudformation-awscommunity-time-sleep-1.1.0a7.tar.gz: cdk-cloudformation-awscommunity-time-sleep-1.1.0a7/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-cloudformation-awscommunity-time-sleep",
    "version": "1.1.0.a7",
    "description": "Sleep a provided number of seconds between create, update, or delete operations.",
    "license": "Apache-2.0",
    "url": "https://github.com/aws-cloudformation/community-registry-extensions.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/cdklabs/cdk-cloudformation.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_cloudformation_awscommunity_time_sleep",
        "cdk_cloudformation_awscommunity_time_sleep._jsii"
    ],
    "package_data": {
        "cdk_cloudformation_awscommunity_time_sleep._jsii": [
            "awscommunity-time-sleep@1.1.0-alpha.7.jsii.tgz"
        ],
        "cdk_cloudformation_awscommunity_time_sleep": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.78.0, <3.0.0",
        "constructs>=10.2.17, <11.0.0",
        "jsii>=1.80.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
